"""
*******
Sloth
*******

**Sloth** is a lightweight CI script to perform push-based actions.

The repo is at `bitbucket.org/moigagoo/configs <https://bitbucket.org/moigagoo/configs>`_.
"""

from .api import main
from .sloth import Sloth
